# ifndef yyUnparse
# define yyUnparse

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"

/* line 20 "FUnparse.puma" */


void FileUnparse ARGS((FILE *f, tTree t));



extern void (* Unparse_Exit) ARGS ((void));

extern void Unparse ARGS ((tTree t));

extern void BeginUnparse ARGS ((void));
extern void CloseUnparse ARGS ((void));

# endif
